@@ -11,47 +11,54 @@
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
-import time
 import datetime
+import getpass
+import json
 import logging
 import os
-import getpass
-import threading
-import json
 import subprocess
+import threading
+import time
 from collections import namedtuple
 from copy import deepcopy
 from hashlib import sha1
+from pathlib import Path
 
 from dateutil.parser import parse
 from dateutil.tz import tzlocal, tzutc
 
-import botocore.configloader
 import botocore.compat
+import botocore.configloader
 from botocore import UNSIGNED
-from botocore.compat import total_seconds
-from botocore.compat import compat_shell_split
+from botocore.compat import compat_shell_split, total_seconds
 from botocore.config import Config
-from botocore.exceptions import UnknownCredentialError
-from botocore.exceptions import PartialCredentialsError
-from botocore.exceptions import ConfigNotFound
-from botocore.exceptions import InvalidConfigError
-from botocore.exceptions import InfiniteLoopConfigError
-from botocore.exceptions import RefreshWithMFAUnsupportedError
-from botocore.exceptions import MetadataRetrievalError
-from botocore.exceptions import CredentialRetrievalError
-from botocore.exceptions import UnauthorizedSSOTokenError
-from botocore.utils import InstanceMetadataFetcher, parse_key_val_file
-from botocore.utils import ContainerMetadataFetcher
-from botocore.utils import FileWebIdentityTokenLoader
-from botocore.utils import SSOTokenLoader
-from botocore.utils import resolve_imds_endpoint_mode
-
+from botocore.exceptions import (
+    ConfigNotFound,
+    CredentialRetrievalError,
+    InfiniteLoopConfigError,
+    InvalidConfigError,
+    MetadataRetrievalError,
+    PartialCredentialsError,
+    RefreshWithMFAUnsupportedError,
+    UnauthorizedSSOTokenError,
+    UnknownCredentialError,
+)
+from botocore.utils import (
+    ContainerMetadataFetcher,
+    FileWebIdentityTokenLoader,
+    InstanceMetadataFetcher,
+    SSOTokenLoader,
+    parse_key_val_file,
+    resolve_imds_endpoint_mode,
+)
 
 logger = logging.getLogger(__name__)
 ReadOnlyCredentials = namedtuple('ReadOnlyCredentials',
                                  ['access_key', 'secret_key', 'token'])
 
+_DEFAULT_MANDATORY_REFRESH_TIMEOUT = 10 * 60  # 10 min
+_DEFAULT_ADVISORY_REFRESH_TIMEOUT = 15 * 60  # 15 min
+
 
 def create_credential_resolver(session, cache=None, region_name=None):
     """Create a default credential resolver.
@@ -70,7 +77,8 @@ def create_credential_resolver(session, cache=None, region_name=None):
         'ec2_metadata_service_endpoint': session.get_config_variable(
             'ec2_metadata_service_endpoint'),
         'ec2_metadata_service_endpoint_mode': resolve_imds_endpoint_mode(
-            session)
+            session),
+        'ec2_credential_refresh_window': _DEFAULT_ADVISORY_REFRESH_TIMEOUT,
     }
 
     if cache is None:
@@ -307,6 +315,14 @@ class JSONFileCache(object):
         except (OSError, ValueError, IOError):
             raise KeyError(cache_key)
 
+    def __delitem__(self, cache_key):
+        actual_key = self._convert_cache_key(cache_key)
+        try:
+            key_path = Path(actual_key)
+            key_path.unlink()
+        except FileNotFoundError:
+            raise KeyError(cache_key)
+
     def __setitem__(self, cache_key, value):
         full_key = self._convert_cache_key(cache_key)
         try:
@@ -330,10 +346,10 @@ class Credentials(object):
     """
     Holds the credentials needed to authenticate requests.
 
-    :ivar access_key: The access key part of the credentials.
-    :ivar secret_key: The secret key part of the credentials.
-    :ivar token: The security token, valid only for session credentials.
-    :ivar method: A string which identifies where the credentials
+    :param str access_key: The access key part of the credentials.
+    :param str secret_key: The secret key part of the credentials.
+    :param str token: The security token, valid only for session credentials.
+    :param str method: A string which identifies where the credentials
         were found.
     """
 
@@ -370,18 +386,20 @@ class RefreshableCredentials(Credentials):
     Holds the credentials needed to authenticate requests. In addition, it
     knows how to refresh itself.
 
-    :ivar access_key: The access key part of the credentials.
-    :ivar secret_key: The secret key part of the credentials.
-    :ivar token: The security token, valid only for session credentials.
-    :ivar method: A string which identifies where the credentials
+    :param str access_key: The access key part of the credentials.
+    :param str secret_key: The secret key part of the credentials.
+    :param str token: The security token, valid only for session credentials.
+    :param function refresh_using: Callback function to refresh the credentials.
+    :param str method: A string which identifies where the credentials
         were found.
+    :param function time_fetcher: Callback function to retrieve current time.
     """
     # The time at which we'll attempt to refresh, but not
     # block if someone else is refreshing.
-    _advisory_refresh_timeout = 15 * 60
+    _advisory_refresh_timeout = _DEFAULT_ADVISORY_REFRESH_TIMEOUT
     # The time at which all threads will block waiting for
     # refreshed credentials.
-    _mandatory_refresh_timeout = 10 * 60
+    _mandatory_refresh_timeout = _DEFAULT_MANDATORY_REFRESH_TIMEOUT
 
     def __init__(self, access_key, secret_key, token,
                  expiry_time, refresh_using, method,
@@ -529,7 +547,7 @@ class RefreshableCredentials(Credentials):
         # the self._refresh_lock.
         try:
             metadata = self._refresh_using()
-        except Exception as e:
+        except Exception:
             period_name = 'mandatory' if is_mandatory else 'advisory'
             logger.warning("Refreshing temporary credentials failed "
                            "during %s refresh period.",
@@ -1486,10 +1504,10 @@ class AssumeRoleProvider(CredentialProvider):
         }
 
         if duration_seconds is not None:
-          try:
-            role_config['duration_seconds'] = int(duration_seconds)
-          except ValueError:
-            pass
+            try:
+                role_config['duration_seconds'] = int(duration_seconds)
+            except ValueError:
+                pass
 
         # Either the credential source or the source profile must be
         # specified, but not both.
@@ -1857,7 +1875,6 @@ class ContainerProvider(CredentialProvider):
         )
 
     def _build_headers(self):
-        headers = {}
         auth_token = self._environ.get(self.ENV_VAR_AUTH_TOKEN)
         if auth_token is not None:
             return {
