@@ -16,36 +16,53 @@
 This module contains builtin handlers for events emitted by botocore.
 """
 
-import os
 import base64
-import logging
 import copy
+import logging
+import os
 import re
-import warnings
 import uuid
+import warnings
 
-from botocore.compat import (
-    unquote, json, six, unquote_str, ensure_bytes, get_md5,
-    OrderedDict, urlsplit, urlunsplit, XMLParseError,
-    ETree, quote,
-)
-from botocore.docs.utils import AutoPopulatedParam
-from botocore.docs.utils import HideParamFromOperations
-from botocore.docs.utils import AppendParamDocumentation
-from botocore.signers import add_generate_presigned_url
-from botocore.signers import add_generate_presigned_post
-from botocore.signers import add_generate_db_auth_token
-from botocore.exceptions import ParamValidationError
-from botocore.exceptions import AliasConflictParameterError
-from botocore.exceptions import UnsupportedTLSVersionWarning
-from botocore.utils import percent_encode, SAFE_CHARS
-from botocore.utils import switch_host_with_param
-from botocore.utils import conditionally_calculate_md5
-from botocore.utils import is_global_accesspoint
-
-from botocore import utils
 import botocore
 import botocore.auth
+from botocore import utils
+from botocore.compat import (
+    ETree,
+    OrderedDict,
+    XMLParseError,
+    ensure_bytes,
+    get_md5,
+    json,
+    quote,
+    six,
+    unquote,
+    unquote_str,
+    urlsplit,
+    urlunsplit,
+)
+from botocore.docs.utils import (
+    AppendParamDocumentation,
+    AutoPopulatedParam,
+    HideParamFromOperations,
+)
+from botocore.exceptions import (
+    AliasConflictParameterError,
+    ParamValidationError,
+    UnsupportedTLSVersionWarning,
+)
+from botocore.signers import (
+    add_generate_db_auth_token,
+    add_generate_presigned_post,
+    add_generate_presigned_url,
+)
+from botocore.utils import (
+    SAFE_CHARS,
+    conditionally_calculate_md5,
+    is_global_accesspoint,
+    percent_encode,
+    switch_host_with_param,
+)
 
 # Keep these imported.  There's pre-existing code that uses them.
 from botocore import retryhandler # noqa
@@ -176,6 +193,19 @@ def set_operation_specific_signer(context, signing_name, **kwargs):
     if auth_type == 'none':
         return botocore.UNSIGNED
 
+    if auth_type == 'v4a':
+        # If sigv4a is chosen, we must add additional
+        # signing config for global signature.
+        signing = {
+            'region': '*',
+            'signing_name': signing_name
+        }
+        if 'signing' in context:
+            context['signing'].update(signing)
+        else:
+            context['signing'] = signing
+        return 'v4a'
+
     if auth_type.startswith('v4'):
         signature_version = 'v4'
         if signing_name == 's3':
