@@ -1,19 +1,22 @@
+import contextlib
 import select
 import socket
-import contextlib
 import threading
-from tests import mock
-from tests import unittest
 from contextlib import contextmanager
 
 import botocore.session
 from botocore.config import Config
-from botocore.vendored.six.moves import BaseHTTPServer, socketserver
 from botocore.exceptions import (
-    ConnectTimeoutError, ReadTimeoutError, EndpointConnectionError,
-    ConnectionClosedError, ClientError, ProxyConnectionError
+    ClientError,
+    ConnectionClosedError,
+    ConnectTimeoutError,
+    EndpointConnectionError,
+    ProxyConnectionError,
+    ReadTimeoutError,
 )
 from botocore.vendored.requests import exceptions as requests_exceptions
+from botocore.vendored.six.moves import BaseHTTPServer, socketserver
+from tests import mock, unittest
 
 
 class TestClientHTTPBehavior(unittest.TestCase):
@@ -95,7 +98,6 @@ class TestClientHTTPBehavior(unittest.TestCase):
         finally:
             self.environ_patch.stop()
 
-
     def _read_timeout_server(self):
         config = Config(
             read_timeout=0.1,
